@@ -54,10 +54,12 @@ boolean_t check_host(const char *hostname);
  * addresses
  * @param address the local address the server will bind to
  * @param port The localhost port number to open
+ * @param family The socket family to use
  * @param backlog The maximum queue length for incomming connections
- * @return The socket ready for accept, or -1 if an error occured.
+ * @return The socket ready for accept
+ * @exception IOException if socket creation failed
  */
-int create_server_socket(const char *address, int port, int backlog);
+int create_server_socket_tcp(const char *address, int port, Socket_Family family, int backlog);
 
 
 /**
@@ -65,7 +67,8 @@ int create_server_socket(const char *address, int port, int backlog);
  * socket path, with the specified backlog.
  * @param address the path to the unix socket
  * @param backlog The maximum queue length for incomming connections
- * @return The socket ready for accept, or -1 if an error occured.
+ * @return The socket ready for accept
+ * @exception IOException if socket creation failed
  */
 int create_server_socket_unix(const char *path, int backlog);
 
